@@ -1,5 +1,5 @@
 package MooX::ChainedAttributes;
-$MooX::ChainedAttributes::VERSION = '0.03';
+$MooX::ChainedAttributes::VERSION = '0.04';
 use strictures 1;
 
 =head1 NAME
@@ -117,6 +117,16 @@ __END__
 
 Aran Clary Deltac <bluefeet@gmail.com>
 
+=head1 CONTRIBUTORS
+
+=over
+
+=item *
+
+Graham Knop <haarg@haarg.org>
+
+=back
+
 =head1 LICENSE
 
 This library is free software; you can redistribute it and/or modify
